@@ -485,7 +485,7 @@ impl Assert {
 impl fmt::Display for Assert {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         let palette = crate::Palette::color();
-        for &(ref name, ref context) in &self.context {
+        for (name, context) in &self.context {
             writeln!(f, "{:#}=`{:#}`", palette.key(name), palette.value(context))?;
         }
         output_fmt(&self.output, f)
@@ -547,7 +547,7 @@ where
 }
 
 /// Keep `predicates` concrete Predicates out of our public API.
-/// [predicates_core::Predicate] used by [`IntoCodePredicate`] for code.
+/// [`predicates_core::Predicate`] used by [`IntoCodePredicate`] for code.
 ///
 /// # Example
 ///
@@ -616,7 +616,7 @@ impl IntoCodePredicate<EqCodePredicate> for i32 {
 }
 
 /// Keep `predicates` concrete Predicates out of our public API.
-/// [predicates_core::Predicate] used by [`IntoCodePredicate`] for iterables of codes.
+/// [`predicates_core::Predicate`] used by [`IntoCodePredicate`] for iterables of codes.
 ///
 /// # Example
 ///
@@ -741,7 +741,7 @@ where
 }
 
 /// Keep `predicates` concrete Predicates out of our public API.
-/// [predicates_core::Predicate] used by [`IntoOutputPredicate`] for bytes.
+/// [`predicates_core::Predicate`] used by [`IntoOutputPredicate`] for bytes.
 ///
 /// # Example
 ///
@@ -781,7 +781,7 @@ impl predicates_core::Predicate<[u8]> for BytesContentOutputPredicate {
         &self,
         expected: bool,
         variable: &[u8],
-    ) -> Option<predicates_core::reflection::Case> {
+    ) -> Option<predicates_core::reflection::Case<'_>> {
         let actual = self.eval(variable);
         if expected == actual {
             Some(predicates_core::reflection::Case::new(Some(self), actual))
@@ -814,7 +814,7 @@ impl IntoOutputPredicate<BytesContentOutputPredicate> for &'static [u8] {
 }
 
 /// Keep `predicates` concrete Predicates out of our public API.
-/// [predicates_core::Predicate] used by [`IntoOutputPredicate`] for [`str`].
+/// [`predicates_core::Predicate`] used by [`IntoOutputPredicate`] for [`str`].
 ///
 /// # Example
 ///
@@ -901,7 +901,7 @@ impl IntoOutputPredicate<StrContentOutputPredicate> for &'static str {
 }
 
 // Keep `predicates` concrete Predicates out of our public API.
-/// [predicates_core::Predicate] used by [`IntoOutputPredicate`] for
+/// [`predicates_core::Predicate`] used by [`IntoOutputPredicate`] for
 /// [`Predicate<str>`][predicates_core::Predicate].
 ///
 /// # Example
@@ -1068,9 +1068,10 @@ impl fmt::Display for AssertError {
         match &self.reason {
             AssertReason::UnexpectedFailure { actual_code } => writeln!(
                 f,
-                "Unexpected failure.\ncode-{}\nstderr=```{}```",
-                actual_code.map_or("<interrupted>".to_owned(), |actual_code| actual_code
-                    .to_string()),
+                "Unexpected failure.\ncode={}\nstderr=```{}```",
+                actual_code
+                    .map(|actual_code| actual_code.to_string())
+                    .unwrap_or_else(|| "<interrupted>".to_owned()),
                 DebugBytes::new(&self.assert.output.stderr),
             ),
             AssertReason::UnexpectedSuccess => {
@@ -1122,7 +1123,7 @@ mod test {
     fn convert_code<I, P>(pred: I) -> P
     where
         I: IntoCodePredicate<P>,
-        P: predicates_core::Predicate<i32>,
+        P: Predicate<i32>,
     {
         pred.into_code()
     }
@@ -1156,7 +1157,7 @@ mod test {
     fn convert_output<I, P>(pred: I) -> P
     where
         I: IntoOutputPredicate<P>,
-        P: predicates_core::Predicate<[u8]>,
+        P: Predicate<[u8]>,
     {
         pred.into_output()
     }
